@@ -9,11 +9,13 @@ package CGI::FormBuilder::Messages::locale;
 use strict;
 use utf8;
 
-our $REVISION = do { (my $r='$Revision: 100 $') =~ s/\D+//g; $r };
-our $VERSION = '3.06';
+use CGI::FormBuilder::Messages::default;
+use base 'CGI::FormBuilder::Messages::default';
 
-# First, create a hash of messages for this language
-our %MESSAGES = (
+our $VERSION = '3.09';
+
+# Define messages for this language
+__PACKAGE__->define_messages({
     lang                  => 'no_NO',
     charset               => 'utf-8',
 
@@ -63,12 +65,7 @@ og vil bli behandlet så snart som mulig..
 
 Om du har spørsmål, ta kontakt med oss ved å svare på denne e-post.
 EOT
-);
-
-# This method should remain unchanged
-sub messages {
-    return wantarray ? %MESSAGES : \%MESSAGES;
-}
+});
 
 1;
 __END__
